# _ChRIS_ Client Library for Rust

[![crates.io version](https://img.shields.io/crates/v/chris?label=version)](https://crates.io/crates/chris)
[![codecov](https://codecov.io/gh/FNNDSC/chrs/branch/master/graph/badge.svg?flag=chris&token=UOYL5NPYIP)](https://codecov.io/gh/FNNDSC/chrs)

Client library for [_ChRIS_](https://chrisproject.org/) built
on [reqwest](https://crates.io/crates/reqwest).

https://docs.rs/chris/latest/chris/
